==> haskell-base16-bytestring-0.1.1.6-9-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base16-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base16-bytestring
version: 0.1.1.6
id: base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
key: base16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
license: BSD-3-Clause
copyright: 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/base16-bytestring
synopsis: Fast base16 (hex) encoding and decoding for ByteStrings
description:
    Fast base16 (hex) encoding and decoding for ByteStrings
category: Data
abi: bba358ad6d6aaa259e18cb7e07ede79c
exposed: True
exposed-modules:
    Data.ByteString.Base16 Data.ByteString.Base16.Lazy
import-dirs: /usr/lib/ghc-8.4.3/site-local/base16-bytestring-0.1.1.6
library-dirs: /usr/lib/ghc-8.4.3/site-local/base16-bytestring-0.1.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/base16-bytestring-0.1.1.6
hs-libraries: HSbase16-bytestring-0.1.1.6-I0igvRcEwRNBMqqPC2yQBh
depends:
    base-4.11.1.0 bytestring-0.10.8.2 ghc-prim-0.5.2.0
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
haddock-interfaces: /usr/share/doc/haskell-base16-bytestring/html/base16-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base16-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-base16-bytestring-0.1.1.6-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-base16-bytestring.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: base16-bytestring
version: 0.1.1.6
id: base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
key: base16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
license: BSD-3-Clause
copyright: 2010 Bryan O'\''Sullivan
maintainer: Bryan O'\''Sullivan <bos@serpentine.com>
author: Bryan O'\''Sullivan <bos@serpentine.com>
homepage: http://github.com/bos/base16-bytestring
synopsis: Fast base16 (hex) encoding and decoding for ByteStrings
description:
    Fast base16 (hex) encoding and decoding for ByteStrings
category: Data
abi: e66eb2b1fb2b94a4134bab5c57df6f79
exposed: True
exposed-modules:
    Data.ByteString.Base16 Data.ByteString.Base16.Lazy
import-dirs: /usr/lib/ghc-8.6.1/site-local/base16-bytestring-0.1.1.6
library-dirs: /usr/lib/ghc-8.6.1/site-local/base16-bytestring-0.1.1.6
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.6.1/base16-bytestring-0.1.1.6
hs-libraries: HSbase16-bytestring-0.1.1.6-17atVnUhDnM13pAkKbwL6I
depends:
    base-4.12.0.0 bytestring-0.10.8.2 ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-base16-bytestring/html/base16-bytestring.haddock
haddock-html: /usr/share/doc/haskell-base16-bytestring/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
